@@ -74,10 +74,6 @@ class VM(object):
         """Make a harddisk immutable or normal."""
         raise
 
-    def autoreset_hd(self, hdd_path, autoreset):
-        """Set the autoreset flag of differencing harddisks."""
-        raise
-
     def remove_hd(self):
         """Remove a harddisk."""
         raise
