@@ -104,10 +104,6 @@ class VirtualBox(VM):
     def immutable_hd(self):
         self._call('modifyhd', self.hdd_path, type_='immutable', compact=True)
 
-    def autoreset_hd(self, hdd_path, autoreset):
-        self._call('modifyhd', hdd_path,
-                   autoreset='on' if autoreset else 'off')
-
     def remove_hd(self):
         self._call('storagectl', self.name, portcount=0,
                    name='IDE', remove=True)
